Testing — Shopyo documentation

# Testing

For pytests, run all tests inside `shopyo/shopyo` directory

    # tests with compact output
    python -m pytest .

    # test with verbose output
    python -m pytest -v

Alternatively, you can run your tests via tox.

run all tests, for all supported Python interpreters

    tox

run all tests, on Python 3.8 only

    tox -e py38

run all only the test_home_page test, on Python 3.9 only

    tox -e py39 -- -k test_shop_home_page